Helpers for windowed parallel execution of futures or tasks.
This provides helpers to spawn or join a set of futures or async tasks while limiting the number of parallel operations to a configurable window size to avoid overwhelming the executor or target services.
Structs
- Future
Window - Resolve a collection of futures using a window of maximum parallel tasks
Functions
- exec_
windowed_ ordered - Execute an async closure for a provided set of inputs returning an collection of results matching the order of the input iterator
- exec_
windowed_ unordered - Execute an async closure for a provided set of inputs returning an unordered collection of results
- join_
windowed_ ordered - Join a provided set of futures returning an collection of results matching the order of the input iterator
- join_
windowed_ unordered - Join a provided set of futures returning an unordered collection of results